Package io.spring.javaformat.formatter
Class FileEdit
- java.lang.Object
-
- io.spring.javaformat.formatter.FileEdit
-
public class FileEdit extends Object
An Edit that can be applied to a File.- Author:
- Phillip Webb
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description FilegetFile()StringgetFormattedContent()booleanhasEdits()voidsave()
-