Class StreamsEdit

java.lang.Object
io.spring.javaformat.formatter.Edit
io.spring.javaformat.formatter.StreamsEdit

public class StreamsEdit extends Edit
An Edit that can be applied to IO Streams.
Author:
Phillip Webb
  • Method Details

    • writeTo

      public void writeTo(OutputStream outputStream)
      Write the edited content to the given OutputStream.
      Parameters:
      outputStream - the output stream where formatted content should be written
    • writeTo

      public void writeTo(OutputStream outputStream, Charset encoding)
      Write the edited content to the given OutputStream.
      Parameters:
      outputStream - the output stream where formatted content should be written
      encoding - the source encoding
    • writeTo

      public void writeTo(Appendable appendable)
      Write the edited content to the given Appendable.
      Parameters:
      appendable - the appendable where formatted content should be written