Index
All Classes and Interfaces|All Packages|Serialized Form
A
- apply(int, TokenManager, ASTNode) - Method in class io.spring.javaformat.formatter.jdk17.eclipse.JSpecifyPreparator
- apply(int, TokenManager, ASTNode) - Method in class io.spring.javaformat.formatter.jdk8.eclipse.JSpecifyPreparator
C
- createIndentationString(int) - Method in interface io.spring.javaformat.formatter.eclipse.EclipseCodeFormatter
- createIndentationString(int) - Method in class io.spring.javaformat.formatter.Formatter
D
- DEFAULT_LINE_SEPARATOR - Static variable in class io.spring.javaformat.formatter.Formatter
-
The default line separator.
E
- EclipseCodeFormatter - Interface in io.spring.javaformat.formatter.eclipse
-
Internal interface used to access an Eclipse
CodeFormatterimplementation. - EclipseJdk17CodeFormatter - Class in io.spring.javaformat.formatter.jdk17.eclipse
-
Internal delegate JDK 17 baseline
EclipseCodeFormatterto apply Spring formatter.prefs and addPreparators. - EclipseJdk17CodeFormatter(JavaFormatConfig) - Constructor for class io.spring.javaformat.formatter.jdk17.eclipse.EclipseJdk17CodeFormatter
- EclipseJdk8CodeFormatter - Class in io.spring.javaformat.formatter.jdk8.eclipse
-
Internal delegate JDK 8 baseline
EclipseCodeFormatterto apply Spring formatter.prefs and addPreparators. - EclipseJdk8CodeFormatter(JavaFormatConfig) - Constructor for class io.spring.javaformat.formatter.jdk8.eclipse.EclipseJdk8CodeFormatter
- Edit - Class in io.spring.javaformat.formatter
-
Base class for edits that can be applied to content.
- Edit(String, TextEdit) - Constructor for class io.spring.javaformat.formatter.Edit
F
- FileEdit - Class in io.spring.javaformat.formatter
- FileFormatter - Class in io.spring.javaformat.formatter
-
A code formatter designed to work with
Files. - FileFormatter() - Constructor for class io.spring.javaformat.formatter.FileFormatter
- FileFormatter(JavaFormatConfig) - Constructor for class io.spring.javaformat.formatter.FileFormatter
- FileFormatter(Formatter) - Constructor for class io.spring.javaformat.formatter.FileFormatter
- FileFormatterException - Exception in io.spring.javaformat.formatter
-
Runtime Exception thrown on
FileFormattererrors. - format(int, String, int, int, int, String) - Method in interface io.spring.javaformat.formatter.eclipse.EclipseCodeFormatter
- format(int, String, int, int, int, String) - Method in class io.spring.javaformat.formatter.Formatter
- format(int, String, IRegion[], int, String) - Method in interface io.spring.javaformat.formatter.eclipse.EclipseCodeFormatter
- format(int, String, IRegion[], int, String) - Method in class io.spring.javaformat.formatter.Formatter
- format(InputStream) - Method in class io.spring.javaformat.formatter.StreamsFormatter
-
Format content from the given source
InputStreamand return aStreamsEditinstance. - format(InputStream, Charset) - Method in class io.spring.javaformat.formatter.StreamsFormatter
-
Format content from the given source
InputStreamand return aStreamsEditinstance. - format(InputStream, Charset, String) - Method in class io.spring.javaformat.formatter.StreamsFormatter
-
Format content from the given source
InputStreamand return aStreamsEditinstance. - format(Reader) - Method in class io.spring.javaformat.formatter.StreamsFormatter
-
Format content from the given source
Readerand return aStreamsEditinstance. - format(Reader, String) - Method in class io.spring.javaformat.formatter.StreamsFormatter
-
Format content from the given source
Readerand return aStreamsEditinstance. - format(String) - Method in class io.spring.javaformat.formatter.Formatter
-
Format the given source content.
- format(String, int, int) - Method in class io.spring.javaformat.formatter.Formatter
-
Format a specific subsection of the given source content.
- format(String, int, int, String) - Method in class io.spring.javaformat.formatter.Formatter
-
Format a specific subsection of the given source content.
- format(String, String) - Method in class io.spring.javaformat.formatter.Formatter
-
Format the given source content.
- format(String, IRegion[]) - Method in class io.spring.javaformat.formatter.Formatter
-
Format specific subsections of the given source content.
- format(String, IRegion[], String) - Method in class io.spring.javaformat.formatter.Formatter
-
Format specific subsections of the given source content.
- formatFile(File, Charset) - Method in class io.spring.javaformat.formatter.FileFormatter
-
Format the given source file and return a
FileEditinstance. - formatFile(File, Charset, String) - Method in class io.spring.javaformat.formatter.FileFormatter
-
Format the given source file and return a
FileEditinstance. - formatFiles(Iterable<File>, Charset) - Method in class io.spring.javaformat.formatter.FileFormatter
- formatFiles(Iterable<File>, Charset, String) - Method in class io.spring.javaformat.formatter.FileFormatter
- formatFiles(Stream<File>, Charset) - Method in class io.spring.javaformat.formatter.FileFormatter
- formatFiles(Stream<File>, Charset, String) - Method in class io.spring.javaformat.formatter.FileFormatter
- Formatter - Class in io.spring.javaformat.formatter
-
A code formatter that applies Spring formatting conventions.
- Formatter() - Constructor for class io.spring.javaformat.formatter.Formatter
-
Create a new formatter instance.
- Formatter(JavaFormatConfig) - Constructor for class io.spring.javaformat.formatter.Formatter
-
Create a new formatter instance.
G
- getFile() - Method in class io.spring.javaformat.formatter.FileEdit
- getFile() - Method in exception io.spring.javaformat.formatter.FileFormatterException
-
Return the file being processed when the exception occured.
- getFormattedContent() - Method in class io.spring.javaformat.formatter.Edit
- getFormattedContent() - Method in class io.spring.javaformat.formatter.FileEdit
H
- hasEdits() - Method in class io.spring.javaformat.formatter.Edit
I
- io.spring.javaformat.formatter - package io.spring.javaformat.formatter
- io.spring.javaformat.formatter.eclipse - package io.spring.javaformat.formatter.eclipse
- io.spring.javaformat.formatter.jdk17.eclipse - package io.spring.javaformat.formatter.jdk17.eclipse
- io.spring.javaformat.formatter.jdk8.eclipse - package io.spring.javaformat.formatter.jdk8.eclipse
J
- JSpecifyPreparator - Class in io.spring.javaformat.formatter.jdk17.eclipse
- JSpecifyPreparator - Class in io.spring.javaformat.formatter.jdk8.eclipse
- JSpecifyPreparator() - Constructor for class io.spring.javaformat.formatter.jdk17.eclipse.JSpecifyPreparator
- JSpecifyPreparator() - Constructor for class io.spring.javaformat.formatter.jdk8.eclipse.JSpecifyPreparator
L
- load(JavaFormatConfig) - Method in class io.spring.javaformat.formatter.eclipse.Options
O
- Options - Class in io.spring.javaformat.formatter.eclipse
-
Utility class used to load formatter options.
- Options(String) - Constructor for class io.spring.javaformat.formatter.eclipse.Options
S
- save() - Method in class io.spring.javaformat.formatter.FileEdit
- setOptions(Map<String, String>) - Method in interface io.spring.javaformat.formatter.eclipse.EclipseCodeFormatter
- setOptions(Map<String, String>) - Method in class io.spring.javaformat.formatter.Formatter
- setOptions(Map<String, String>) - Method in class io.spring.javaformat.formatter.jdk17.eclipse.EclipseJdk17CodeFormatter
- setOptions(Map<String, String>) - Method in class io.spring.javaformat.formatter.jdk8.eclipse.EclipseJdk8CodeFormatter
- StreamsEdit - Class in io.spring.javaformat.formatter
-
An
Editthat can be applied to IO Streams. - StreamsFormatter - Class in io.spring.javaformat.formatter
-
A code formatter designed to work with IO streams.
- StreamsFormatter() - Constructor for class io.spring.javaformat.formatter.StreamsFormatter
- StreamsFormatter(JavaFormatConfig) - Constructor for class io.spring.javaformat.formatter.StreamsFormatter
- StreamsFormatter(Formatter) - Constructor for class io.spring.javaformat.formatter.StreamsFormatter
W
- writeTo(OutputStream) - Method in class io.spring.javaformat.formatter.StreamsEdit
-
Write the edited content to the given
OutputStream. - writeTo(OutputStream, Charset) - Method in class io.spring.javaformat.formatter.StreamsEdit
-
Write the edited content to the given
OutputStream. - writeTo(Appendable) - Method in class io.spring.javaformat.formatter.StreamsEdit
-
Write the edited content to the given
Appendable.
All Classes and Interfaces|All Packages|Serialized Form