Package io.spring.javaformat.formatter
Class StreamsEdit
java.lang.Object
io.spring.javaformat.formatter.Edit
io.spring.javaformat.formatter.StreamsEdit
An
Edit that can be applied to IO Streams.- Author:
- Phillip Webb
-
Method Summary
Modifier and TypeMethodDescriptionvoidwriteTo(OutputStream outputStream) Write the edited content to the givenOutputStream.voidwriteTo(OutputStream outputStream, Charset encoding) Write the edited content to the givenOutputStream.voidwriteTo(Appendable appendable) Write the edited content to the givenAppendable.Methods inherited from class io.spring.javaformat.formatter.Edit
getFormattedContent, hasEdits
-
Method Details
-
writeTo
Write the edited content to the givenOutputStream.- Parameters:
outputStream- the output stream where formatted content should be written
-
writeTo
Write the edited content to the givenOutputStream.- Parameters:
outputStream- the output stream where formatted content should be writtenencoding- the source encoding
-
writeTo
Write the edited content to the givenAppendable.- Parameters:
appendable- the appendable where formatted content should be written
-